import numpy as np

from .mc_cov import mc_cov

def multi_ess(x, b=None, r=3):
    num_iters, num_pars = x.shape

    cov_mat_det = np.linalg.det(np.cov(x.transpose()))
    mc_cov_mat_det = np.linalg.det(mc_cov(x, b=b, r=r))

    return num_iters * ((cov_mat_det / mc_cov_mat_det) ** (1/num_pars))



import arviz as az

# x is a numpy array of 3 dimensions, (chain, MC iteration, parameter)
def rhat(x, var_names=None, method='folded', vars=None):
    return [az.rhat(x.transpose()[i].transpose(), method=method) for i in vars or range(x.shape[2])]
